pub struct CocoonServiceClient<T> {
inner: Grpc<T>,
}Expand description
Service running on the Cocoon sidecar, listening for requests from Mountain.
Fields
inner: Grpc<T>Implementations
Sourceimpl CocoonServiceClient<Channel>
impl CocoonServiceClient<Channel>
Sourceimpl<T> CocoonServiceClient<T>
impl<T> CocoonServiceClient<T>
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> CocoonServiceClient<InterceptedService<T, F>>
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn process_mountain_request(
&mut self,
request: impl IntoRequest<GenericRequest>,
) -> Result<Response<GenericResponse>, Status>
pub async fn process_mountain_request( &mut self, request: impl IntoRequest<GenericRequest>, ) -> Result<Response<GenericResponse>, Status>
A generic request-response method for Mountain to call a function on Cocoon.
Sourcepub async fn send_mountain_notification(
&mut self,
request: impl IntoRequest<GenericNotification>,
) -> Result<Response<Empty>, Status>
pub async fn send_mountain_notification( &mut self, request: impl IntoRequest<GenericNotification>, ) -> Result<Response<Empty>, Status>
A generic fire-and-forget method for Mountain to send a notification to Cocoon.
Sourcepub async fn cancel_operation(
&mut self,
request: impl IntoRequest<CancelOperationRequest>,
) -> Result<Response<Empty>, Status>
pub async fn cancel_operation( &mut self, request: impl IntoRequest<CancelOperationRequest>, ) -> Result<Response<Empty>, Status>
A method for Mountain to request that Cocoon cancel a long-running operation.
Sourcepub async fn open_channel_from_mountain(
&mut self,
request: impl IntoStreamingRequest<Message = Envelope>,
) -> Result<Response<Streaming<Envelope>>, Status>
pub async fn open_channel_from_mountain( &mut self, request: impl IntoStreamingRequest<Message = Envelope>, ) -> Result<Response<Streaming<Envelope>>, Status>
LAND-PATCH B7-S6 P2: bidirectional streaming channel (mirror of MountainService::OpenChannelFromCocoon). Mountain opens this stream once per Cocoon connection; all subsequent traffic multiplexes over it. Reverses the call direction so Mountain is the streaming initiator (which matches the typical “client opens stream, server replies” gRPC idiom).
Sourcepub async fn initial_handshake(
&mut self,
request: impl IntoRequest<Empty>,
) -> Result<Response<Empty>, Status>
pub async fn initial_handshake( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<Empty>, Status>
Handshake - Called by Cocoon to signal readiness
Sourcepub async fn init_extension_host(
&mut self,
request: impl IntoRequest<InitExtensionHostRequest>,
) -> Result<Response<Empty>, Status>
pub async fn init_extension_host( &mut self, request: impl IntoRequest<InitExtensionHostRequest>, ) -> Result<Response<Empty>, Status>
Initialize Extension Host - Mountain sends initialization data to Cocoon
Sourcepub async fn register_command(
&mut self,
request: impl IntoRequest<RegisterCommandRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_command( &mut self, request: impl IntoRequest<RegisterCommandRequest>, ) -> Result<Response<Empty>, Status>
Register Command - Cocoon registers an extension command
Sourcepub async fn execute_contributed_command(
&mut self,
request: impl IntoRequest<ExecuteCommandRequest>,
) -> Result<Response<ExecuteCommandResponse>, Status>
pub async fn execute_contributed_command( &mut self, request: impl IntoRequest<ExecuteCommandRequest>, ) -> Result<Response<ExecuteCommandResponse>, Status>
Execute Contributed Command - Mountain executes an extension command
Sourcepub async fn unregister_command(
&mut self,
request: impl IntoRequest<UnregisterCommandRequest>,
) -> Result<Response<Empty>, Status>
pub async fn unregister_command( &mut self, request: impl IntoRequest<UnregisterCommandRequest>, ) -> Result<Response<Empty>, Status>
Unregister Command - Unregister a previously registered command
Sourcepub async fn register_hover_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_hover_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Hover Provider - Register a hover provider
Sourcepub async fn provide_hover(
&mut self,
request: impl IntoRequest<ProvideHoverRequest>,
) -> Result<Response<ProvideHoverResponse>, Status>
pub async fn provide_hover( &mut self, request: impl IntoRequest<ProvideHoverRequest>, ) -> Result<Response<ProvideHoverResponse>, Status>
Provide Hover - Request hover information
Sourcepub async fn register_completion_item_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_completion_item_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Completion Item Provider - Register a completion provider
Sourcepub async fn provide_completion_items(
&mut self,
request: impl IntoRequest<ProvideCompletionItemsRequest>,
) -> Result<Response<ProvideCompletionItemsResponse>, Status>
pub async fn provide_completion_items( &mut self, request: impl IntoRequest<ProvideCompletionItemsRequest>, ) -> Result<Response<ProvideCompletionItemsResponse>, Status>
Provide Completion Items - Request completion items
Sourcepub async fn register_definition_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_definition_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Definition Provider - Register a definition provider
Sourcepub async fn provide_definition(
&mut self,
request: impl IntoRequest<ProvideDefinitionRequest>,
) -> Result<Response<ProvideDefinitionResponse>, Status>
pub async fn provide_definition( &mut self, request: impl IntoRequest<ProvideDefinitionRequest>, ) -> Result<Response<ProvideDefinitionResponse>, Status>
Provide Definition - Request definition location
Sourcepub async fn register_reference_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_reference_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Reference Provider - Register a reference provider
Sourcepub async fn provide_references(
&mut self,
request: impl IntoRequest<ProvideReferencesRequest>,
) -> Result<Response<ProvideReferencesResponse>, Status>
pub async fn provide_references( &mut self, request: impl IntoRequest<ProvideReferencesRequest>, ) -> Result<Response<ProvideReferencesResponse>, Status>
Provide References - Request references
Sourcepub async fn register_code_actions_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_code_actions_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Code Actions Provider - Register code actions provider
Sourcepub async fn provide_code_actions(
&mut self,
request: impl IntoRequest<ProvideCodeActionsRequest>,
) -> Result<Response<ProvideCodeActionsResponse>, Status>
pub async fn provide_code_actions( &mut self, request: impl IntoRequest<ProvideCodeActionsRequest>, ) -> Result<Response<ProvideCodeActionsResponse>, Status>
Provide Code Actions - Request code actions
Sourcepub async fn register_document_highlight_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_document_highlight_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Document Highlight Provider
Sourcepub async fn provide_document_highlights(
&mut self,
request: impl IntoRequest<ProvideDocumentHighlightsRequest>,
) -> Result<Response<ProvideDocumentHighlightsResponse>, Status>
pub async fn provide_document_highlights( &mut self, request: impl IntoRequest<ProvideDocumentHighlightsRequest>, ) -> Result<Response<ProvideDocumentHighlightsResponse>, Status>
Provide Document Highlights
Sourcepub async fn register_document_symbol_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_document_symbol_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Document Symbol Provider
Sourcepub async fn provide_document_symbols(
&mut self,
request: impl IntoRequest<ProvideDocumentSymbolsRequest>,
) -> Result<Response<ProvideDocumentSymbolsResponse>, Status>
pub async fn provide_document_symbols( &mut self, request: impl IntoRequest<ProvideDocumentSymbolsRequest>, ) -> Result<Response<ProvideDocumentSymbolsResponse>, Status>
Provide Document Symbols
Sourcepub async fn register_workspace_symbol_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_workspace_symbol_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Workspace Symbol Provider
Sourcepub async fn provide_workspace_symbols(
&mut self,
request: impl IntoRequest<ProvideWorkspaceSymbolsRequest>,
) -> Result<Response<ProvideWorkspaceSymbolsResponse>, Status>
pub async fn provide_workspace_symbols( &mut self, request: impl IntoRequest<ProvideWorkspaceSymbolsRequest>, ) -> Result<Response<ProvideWorkspaceSymbolsResponse>, Status>
Provide Workspace Symbols
Sourcepub async fn register_rename_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_rename_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Rename Provider
Sourcepub async fn provide_rename_edits(
&mut self,
request: impl IntoRequest<ProvideRenameEditsRequest>,
) -> Result<Response<ProvideRenameEditsResponse>, Status>
pub async fn provide_rename_edits( &mut self, request: impl IntoRequest<ProvideRenameEditsRequest>, ) -> Result<Response<ProvideRenameEditsResponse>, Status>
Provide Rename Edits
Sourcepub async fn register_document_formatting_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_document_formatting_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Document Formatting Provider
Sourcepub async fn provide_document_formatting(
&mut self,
request: impl IntoRequest<ProvideDocumentFormattingRequest>,
) -> Result<Response<ProvideDocumentFormattingResponse>, Status>
pub async fn provide_document_formatting( &mut self, request: impl IntoRequest<ProvideDocumentFormattingRequest>, ) -> Result<Response<ProvideDocumentFormattingResponse>, Status>
Provide Document Formatting
Sourcepub async fn register_document_range_formatting_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_document_range_formatting_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Document Range Formatting Provider
Sourcepub async fn provide_document_range_formatting(
&mut self,
request: impl IntoRequest<ProvideDocumentRangeFormattingRequest>,
) -> Result<Response<ProvideDocumentRangeFormattingResponse>, Status>
pub async fn provide_document_range_formatting( &mut self, request: impl IntoRequest<ProvideDocumentRangeFormattingRequest>, ) -> Result<Response<ProvideDocumentRangeFormattingResponse>, Status>
Provide Document Range Formatting
Sourcepub async fn register_on_type_formatting_provider(
&mut self,
request: impl IntoRequest<RegisterOnTypeFormattingProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_on_type_formatting_provider( &mut self, request: impl IntoRequest<RegisterOnTypeFormattingProviderRequest>, ) -> Result<Response<Empty>, Status>
Register On Type Formatting Provider
Sourcepub async fn provide_on_type_formatting(
&mut self,
request: impl IntoRequest<ProvideOnTypeFormattingRequest>,
) -> Result<Response<ProvideOnTypeFormattingResponse>, Status>
pub async fn provide_on_type_formatting( &mut self, request: impl IntoRequest<ProvideOnTypeFormattingRequest>, ) -> Result<Response<ProvideOnTypeFormattingResponse>, Status>
Provide On Type Formatting
Sourcepub async fn register_signature_help_provider(
&mut self,
request: impl IntoRequest<RegisterSignatureHelpProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_signature_help_provider( &mut self, request: impl IntoRequest<RegisterSignatureHelpProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Signature Help Provider
Sourcepub async fn provide_signature_help(
&mut self,
request: impl IntoRequest<ProvideSignatureHelpRequest>,
) -> Result<Response<ProvideSignatureHelpResponse>, Status>
pub async fn provide_signature_help( &mut self, request: impl IntoRequest<ProvideSignatureHelpRequest>, ) -> Result<Response<ProvideSignatureHelpResponse>, Status>
Provide Signature Help
Sourcepub async fn register_code_lens_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_code_lens_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Code Lens Provider
Sourcepub async fn provide_code_lenses(
&mut self,
request: impl IntoRequest<ProvideCodeLensesRequest>,
) -> Result<Response<ProvideCodeLensesResponse>, Status>
pub async fn provide_code_lenses( &mut self, request: impl IntoRequest<ProvideCodeLensesRequest>, ) -> Result<Response<ProvideCodeLensesResponse>, Status>
Provide Code Lenses
Sourcepub async fn register_folding_range_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_folding_range_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Folding Range Provider
Sourcepub async fn provide_folding_ranges(
&mut self,
request: impl IntoRequest<ProvideFoldingRangesRequest>,
) -> Result<Response<ProvideFoldingRangesResponse>, Status>
pub async fn provide_folding_ranges( &mut self, request: impl IntoRequest<ProvideFoldingRangesRequest>, ) -> Result<Response<ProvideFoldingRangesResponse>, Status>
Provide Folding Ranges
Sourcepub async fn register_selection_range_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_selection_range_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Selection Range Provider
Sourcepub async fn provide_selection_ranges(
&mut self,
request: impl IntoRequest<ProvideSelectionRangesRequest>,
) -> Result<Response<ProvideSelectionRangesResponse>, Status>
pub async fn provide_selection_ranges( &mut self, request: impl IntoRequest<ProvideSelectionRangesRequest>, ) -> Result<Response<ProvideSelectionRangesResponse>, Status>
Provide Selection Ranges
Sourcepub async fn register_semantic_tokens_provider(
&mut self,
request: impl IntoRequest<RegisterSemanticTokensProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_semantic_tokens_provider( &mut self, request: impl IntoRequest<RegisterSemanticTokensProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Semantic Tokens Provider
Sourcepub async fn provide_semantic_tokens_full(
&mut self,
request: impl IntoRequest<ProvideSemanticTokensRequest>,
) -> Result<Response<ProvideSemanticTokensResponse>, Status>
pub async fn provide_semantic_tokens_full( &mut self, request: impl IntoRequest<ProvideSemanticTokensRequest>, ) -> Result<Response<ProvideSemanticTokensResponse>, Status>
Provide Semantic Tokens Full
Sourcepub async fn register_inlay_hints_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_inlay_hints_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Inlay Hints Provider
Sourcepub async fn provide_inlay_hints(
&mut self,
request: impl IntoRequest<ProvideInlayHintsRequest>,
) -> Result<Response<ProvideInlayHintsResponse>, Status>
pub async fn provide_inlay_hints( &mut self, request: impl IntoRequest<ProvideInlayHintsRequest>, ) -> Result<Response<ProvideInlayHintsResponse>, Status>
Provide Inlay Hints
Sourcepub async fn register_type_hierarchy_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_type_hierarchy_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Type Hierarchy Provider
Sourcepub async fn provide_type_hierarchy_supertypes(
&mut self,
request: impl IntoRequest<ProvideTypeHierarchyRequest>,
) -> Result<Response<ProvideTypeHierarchyResponse>, Status>
pub async fn provide_type_hierarchy_supertypes( &mut self, request: impl IntoRequest<ProvideTypeHierarchyRequest>, ) -> Result<Response<ProvideTypeHierarchyResponse>, Status>
Provide Type Hierarchy Supertypes
Sourcepub async fn provide_type_hierarchy_subtypes(
&mut self,
request: impl IntoRequest<ProvideTypeHierarchyRequest>,
) -> Result<Response<ProvideTypeHierarchyResponse>, Status>
pub async fn provide_type_hierarchy_subtypes( &mut self, request: impl IntoRequest<ProvideTypeHierarchyRequest>, ) -> Result<Response<ProvideTypeHierarchyResponse>, Status>
Provide Type Hierarchy Subtypes
Sourcepub async fn register_call_hierarchy_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_call_hierarchy_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Call Hierarchy Provider
Sourcepub async fn provide_call_hierarchy_incoming_calls(
&mut self,
request: impl IntoRequest<ProvideCallHierarchyRequest>,
) -> Result<Response<ProvideCallHierarchyResponse>, Status>
pub async fn provide_call_hierarchy_incoming_calls( &mut self, request: impl IntoRequest<ProvideCallHierarchyRequest>, ) -> Result<Response<ProvideCallHierarchyResponse>, Status>
Provide Call Hierarchy Incoming Calls
Sourcepub async fn provide_call_hierarchy_outgoing_calls(
&mut self,
request: impl IntoRequest<ProvideCallHierarchyRequest>,
) -> Result<Response<ProvideCallHierarchyResponse>, Status>
pub async fn provide_call_hierarchy_outgoing_calls( &mut self, request: impl IntoRequest<ProvideCallHierarchyRequest>, ) -> Result<Response<ProvideCallHierarchyResponse>, Status>
Provide Call Hierarchy Outgoing Calls
Sourcepub async fn register_linked_editing_range_provider(
&mut self,
request: impl IntoRequest<RegisterProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_linked_editing_range_provider( &mut self, request: impl IntoRequest<RegisterProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Linked Editing Range Provider
Sourcepub async fn provide_linked_editing_ranges(
&mut self,
request: impl IntoRequest<ProvideLinkedEditingRangesRequest>,
) -> Result<Response<ProvideLinkedEditingRangesResponse>, Status>
pub async fn provide_linked_editing_ranges( &mut self, request: impl IntoRequest<ProvideLinkedEditingRangesRequest>, ) -> Result<Response<ProvideLinkedEditingRangesResponse>, Status>
Provide Linked Editing Ranges
Sourcepub async fn show_quick_pick(
&mut self,
request: impl IntoRequest<ShowQuickPickRequest>,
) -> Result<Response<ShowQuickPickResponse>, Status>
pub async fn show_quick_pick( &mut self, request: impl IntoRequest<ShowQuickPickRequest>, ) -> Result<Response<ShowQuickPickResponse>, Status>
Show Quick Pick
Sourcepub async fn show_input_box(
&mut self,
request: impl IntoRequest<ShowInputBoxRequest>,
) -> Result<Response<ShowInputBoxResponse>, Status>
pub async fn show_input_box( &mut self, request: impl IntoRequest<ShowInputBoxRequest>, ) -> Result<Response<ShowInputBoxResponse>, Status>
Show Input Box
Sourcepub async fn show_progress(
&mut self,
request: impl IntoRequest<ShowProgressRequest>,
) -> Result<Response<ShowProgressResponse>, Status>
pub async fn show_progress( &mut self, request: impl IntoRequest<ShowProgressRequest>, ) -> Result<Response<ShowProgressResponse>, Status>
Show Progress
Sourcepub async fn report_progress(
&mut self,
request: impl IntoRequest<ReportProgressRequest>,
) -> Result<Response<Empty>, Status>
pub async fn report_progress( &mut self, request: impl IntoRequest<ReportProgressRequest>, ) -> Result<Response<Empty>, Status>
Report Progress
Sourcepub async fn post_webview_message(
&mut self,
request: impl IntoRequest<PostWebviewMessageRequest>,
) -> Result<Response<Empty>, Status>
pub async fn post_webview_message( &mut self, request: impl IntoRequest<PostWebviewMessageRequest>, ) -> Result<Response<Empty>, Status>
Post Message to Webview
Sourcepub async fn dispose_webview_panel(
&mut self,
request: impl IntoRequest<DisposeWebviewPanelRequest>,
) -> Result<Response<Empty>, Status>
pub async fn dispose_webview_panel( &mut self, request: impl IntoRequest<DisposeWebviewPanelRequest>, ) -> Result<Response<Empty>, Status>
Dispose Webview Panel
Sourcepub async fn open_external(
&mut self,
request: impl IntoRequest<OpenExternalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn open_external( &mut self, request: impl IntoRequest<OpenExternalRequest>, ) -> Result<Response<Empty>, Status>
Open External URI
Sourcepub async fn delete_file(
&mut self,
request: impl IntoRequest<DeleteFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn delete_file( &mut self, request: impl IntoRequest<DeleteFileRequest>, ) -> Result<Response<Empty>, Status>
Delete File
Sourcepub async fn rename_file(
&mut self,
request: impl IntoRequest<RenameFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn rename_file( &mut self, request: impl IntoRequest<RenameFileRequest>, ) -> Result<Response<Empty>, Status>
Rename File
Sourcepub async fn copy_file(
&mut self,
request: impl IntoRequest<CopyFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn copy_file( &mut self, request: impl IntoRequest<CopyFileRequest>, ) -> Result<Response<Empty>, Status>
Copy File
Sourcepub async fn create_directory(
&mut self,
request: impl IntoRequest<CreateDirectoryRequest>,
) -> Result<Response<Empty>, Status>
pub async fn create_directory( &mut self, request: impl IntoRequest<CreateDirectoryRequest>, ) -> Result<Response<Empty>, Status>
Create Directory
Sourcepub async fn create_output_channel(
&mut self,
request: impl IntoRequest<CreateOutputChannelRequest>,
) -> Result<Response<CreateOutputChannelResponse>, Status>
pub async fn create_output_channel( &mut self, request: impl IntoRequest<CreateOutputChannelRequest>, ) -> Result<Response<CreateOutputChannelResponse>, Status>
Create Output Channel
Sourcepub async fn append_output(
&mut self,
request: impl IntoRequest<AppendOutputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn append_output( &mut self, request: impl IntoRequest<AppendOutputRequest>, ) -> Result<Response<Empty>, Status>
Append to Output Channel
Sourcepub async fn clear_output(
&mut self,
request: impl IntoRequest<ClearOutputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn clear_output( &mut self, request: impl IntoRequest<ClearOutputRequest>, ) -> Result<Response<Empty>, Status>
Clear Output Channel
Sourcepub async fn show_output(
&mut self,
request: impl IntoRequest<ShowOutputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn show_output( &mut self, request: impl IntoRequest<ShowOutputRequest>, ) -> Result<Response<Empty>, Status>
Show Output Channel
Sourcepub async fn dispose_output(
&mut self,
request: impl IntoRequest<DisposeOutputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn dispose_output( &mut self, request: impl IntoRequest<DisposeOutputRequest>, ) -> Result<Response<Empty>, Status>
Dispose Output Channel
Sourcepub async fn register_task_provider(
&mut self,
request: impl IntoRequest<RegisterTaskProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_task_provider( &mut self, request: impl IntoRequest<RegisterTaskProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Task Provider
Sourcepub async fn execute_task(
&mut self,
request: impl IntoRequest<ExecuteTaskRequest>,
) -> Result<Response<ExecuteTaskResponse>, Status>
pub async fn execute_task( &mut self, request: impl IntoRequest<ExecuteTaskRequest>, ) -> Result<Response<ExecuteTaskResponse>, Status>
Execute Task
Sourcepub async fn terminate_task(
&mut self,
request: impl IntoRequest<TerminateTaskRequest>,
) -> Result<Response<Empty>, Status>
pub async fn terminate_task( &mut self, request: impl IntoRequest<TerminateTaskRequest>, ) -> Result<Response<Empty>, Status>
Terminate Task
Sourcepub async fn get_authentication_session(
&mut self,
request: impl IntoRequest<GetAuthenticationSessionRequest>,
) -> Result<Response<GetAuthenticationSessionResponse>, Status>
pub async fn get_authentication_session( &mut self, request: impl IntoRequest<GetAuthenticationSessionRequest>, ) -> Result<Response<GetAuthenticationSessionResponse>, Status>
Get Authentication Session
Sourcepub async fn register_authentication_provider(
&mut self,
request: impl IntoRequest<RegisterAuthenticationProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_authentication_provider( &mut self, request: impl IntoRequest<RegisterAuthenticationProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Authentication Provider
Sourcepub async fn stop_debugging(
&mut self,
request: impl IntoRequest<StopDebuggingRequest>,
) -> Result<Response<Empty>, Status>
pub async fn stop_debugging( &mut self, request: impl IntoRequest<StopDebuggingRequest>, ) -> Result<Response<Empty>, Status>
Stop Debugging
Sourcepub async fn get_extension(
&mut self,
request: impl IntoRequest<GetExtensionRequest>,
) -> Result<Response<GetExtensionResponse>, Status>
pub async fn get_extension( &mut self, request: impl IntoRequest<GetExtensionRequest>, ) -> Result<Response<GetExtensionResponse>, Status>
Get Extension
Sourcepub async fn get_all_extensions(
&mut self,
request: impl IntoRequest<Empty>,
) -> Result<Response<GetAllExtensionsResponse>, Status>
pub async fn get_all_extensions( &mut self, request: impl IntoRequest<Empty>, ) -> Result<Response<GetAllExtensionsResponse>, Status>
Get All Extensions
Sourcepub async fn resize_terminal(
&mut self,
request: impl IntoRequest<ResizeTerminalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn resize_terminal( &mut self, request: impl IntoRequest<ResizeTerminalRequest>, ) -> Result<Response<Empty>, Status>
Resize Terminal
Sourcepub async fn get_configuration(
&mut self,
request: impl IntoRequest<GetConfigurationRequest>,
) -> Result<Response<GetConfigurationResponse>, Status>
pub async fn get_configuration( &mut self, request: impl IntoRequest<GetConfigurationRequest>, ) -> Result<Response<GetConfigurationResponse>, Status>
Get Configuration Value
Sourcepub async fn show_text_document(
&mut self,
request: impl IntoRequest<ShowTextDocumentRequest>,
) -> Result<Response<ShowTextDocumentResponse>, Status>
pub async fn show_text_document( &mut self, request: impl IntoRequest<ShowTextDocumentRequest>, ) -> Result<Response<ShowTextDocumentResponse>, Status>
Show Text Document - Open a text document
Sourcepub async fn show_information_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_information_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Information Message - Display an info message
Sourcepub async fn show_warning_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_warning_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Warning Message - Display a warning message
Sourcepub async fn show_error_message(
&mut self,
request: impl IntoRequest<ShowMessageRequest>,
) -> Result<Response<ShowMessageResponse>, Status>
pub async fn show_error_message( &mut self, request: impl IntoRequest<ShowMessageRequest>, ) -> Result<Response<ShowMessageResponse>, Status>
Show Error Message - Display an error message
Sourcepub async fn create_status_bar_item(
&mut self,
request: impl IntoRequest<CreateStatusBarItemRequest>,
) -> Result<Response<CreateStatusBarItemResponse>, Status>
pub async fn create_status_bar_item( &mut self, request: impl IntoRequest<CreateStatusBarItemRequest>, ) -> Result<Response<CreateStatusBarItemResponse>, Status>
Create Status Bar Item - Create a status bar item
Sourcepub async fn set_status_bar_text(
&mut self,
request: impl IntoRequest<SetStatusBarTextRequest>,
) -> Result<Response<Empty>, Status>
pub async fn set_status_bar_text( &mut self, request: impl IntoRequest<SetStatusBarTextRequest>, ) -> Result<Response<Empty>, Status>
Set Status Bar Text - Set status bar text
Sourcepub async fn create_webview_panel(
&mut self,
request: impl IntoRequest<CreateWebviewPanelRequest>,
) -> Result<Response<CreateWebviewPanelResponse>, Status>
pub async fn create_webview_panel( &mut self, request: impl IntoRequest<CreateWebviewPanelRequest>, ) -> Result<Response<CreateWebviewPanelResponse>, Status>
Create Webview Panel - Create a new webview panel
Sourcepub async fn set_webview_html(
&mut self,
request: impl IntoRequest<SetWebviewHtmlRequest>,
) -> Result<Response<Empty>, Status>
pub async fn set_webview_html( &mut self, request: impl IntoRequest<SetWebviewHtmlRequest>, ) -> Result<Response<Empty>, Status>
Set Webview HTML - Update webview HTML content
Sourcepub async fn on_did_receive_message(
&mut self,
request: impl IntoRequest<OnDidReceiveMessageRequest>,
) -> Result<Response<Empty>, Status>
pub async fn on_did_receive_message( &mut self, request: impl IntoRequest<OnDidReceiveMessageRequest>, ) -> Result<Response<Empty>, Status>
On Did Receive Message - Receive message from webview
Sourcepub async fn read_file(
&mut self,
request: impl IntoRequest<ReadFileRequest>,
) -> Result<Response<ReadFileResponse>, Status>
pub async fn read_file( &mut self, request: impl IntoRequest<ReadFileRequest>, ) -> Result<Response<ReadFileResponse>, Status>
Read File - Read file contents
Sourcepub async fn write_file(
&mut self,
request: impl IntoRequest<WriteFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn write_file( &mut self, request: impl IntoRequest<WriteFileRequest>, ) -> Result<Response<Empty>, Status>
Write File - Write file contents
Sourcepub async fn stat(
&mut self,
request: impl IntoRequest<StatRequest>,
) -> Result<Response<StatResponse>, Status>
pub async fn stat( &mut self, request: impl IntoRequest<StatRequest>, ) -> Result<Response<StatResponse>, Status>
Stat - Get file metadata
Sourcepub async fn readdir(
&mut self,
request: impl IntoRequest<ReaddirRequest>,
) -> Result<Response<ReaddirResponse>, Status>
pub async fn readdir( &mut self, request: impl IntoRequest<ReaddirRequest>, ) -> Result<Response<ReaddirResponse>, Status>
Read Directory - List directory contents
Sourcepub async fn watch_file(
&mut self,
request: impl IntoRequest<WatchFileRequest>,
) -> Result<Response<Empty>, Status>
pub async fn watch_file( &mut self, request: impl IntoRequest<WatchFileRequest>, ) -> Result<Response<Empty>, Status>
Watch File - Watch file for changes
Sourcepub async fn find_files(
&mut self,
request: impl IntoRequest<FindFilesRequest>,
) -> Result<Response<FindFilesResponse>, Status>
pub async fn find_files( &mut self, request: impl IntoRequest<FindFilesRequest>, ) -> Result<Response<FindFilesResponse>, Status>
Find Files - Search for files
Sourcepub async fn find_text_in_files(
&mut self,
request: impl IntoRequest<FindTextInFilesRequest>,
) -> Result<Response<FindTextInFilesResponse>, Status>
pub async fn find_text_in_files( &mut self, request: impl IntoRequest<FindTextInFilesRequest>, ) -> Result<Response<FindTextInFilesResponse>, Status>
Find Text in Files - Search for text across files
Sourcepub async fn open_document(
&mut self,
request: impl IntoRequest<OpenDocumentRequest>,
) -> Result<Response<OpenDocumentResponse>, Status>
pub async fn open_document( &mut self, request: impl IntoRequest<OpenDocumentRequest>, ) -> Result<Response<OpenDocumentResponse>, Status>
Open Document - Open a document
Sourcepub async fn save_all(
&mut self,
request: impl IntoRequest<SaveAllRequest>,
) -> Result<Response<SaveAllResponse>, Status>
pub async fn save_all( &mut self, request: impl IntoRequest<SaveAllRequest>, ) -> Result<Response<SaveAllResponse>, Status>
Save All - Save all open documents
Sourcepub async fn apply_edit(
&mut self,
request: impl IntoRequest<ApplyEditRequest>,
) -> Result<Response<ApplyEditResponse>, Status>
pub async fn apply_edit( &mut self, request: impl IntoRequest<ApplyEditRequest>, ) -> Result<Response<ApplyEditResponse>, Status>
Apply Edit - Apply a text edit to a document
Sourcepub async fn update_configuration(
&mut self,
request: impl IntoRequest<UpdateConfigurationRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_configuration( &mut self, request: impl IntoRequest<UpdateConfigurationRequest>, ) -> Result<Response<Empty>, Status>
Update Configuration - Notify of configuration changes
Sourcepub async fn update_workspace_folders(
&mut self,
request: impl IntoRequest<UpdateWorkspaceFoldersRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_workspace_folders( &mut self, request: impl IntoRequest<UpdateWorkspaceFoldersRequest>, ) -> Result<Response<Empty>, Status>
Update Workspace Folders - Update workspace folders
Sourcepub async fn open_terminal(
&mut self,
request: impl IntoRequest<OpenTerminalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn open_terminal( &mut self, request: impl IntoRequest<OpenTerminalRequest>, ) -> Result<Response<Empty>, Status>
Open Terminal - Open a new terminal
Sourcepub async fn terminal_input(
&mut self,
request: impl IntoRequest<TerminalInputRequest>,
) -> Result<Response<Empty>, Status>
pub async fn terminal_input( &mut self, request: impl IntoRequest<TerminalInputRequest>, ) -> Result<Response<Empty>, Status>
Terminal Input - Send input to terminal
Sourcepub async fn close_terminal(
&mut self,
request: impl IntoRequest<CloseTerminalRequest>,
) -> Result<Response<Empty>, Status>
pub async fn close_terminal( &mut self, request: impl IntoRequest<CloseTerminalRequest>, ) -> Result<Response<Empty>, Status>
Close Terminal - Close a terminal
Sourcepub async fn accept_terminal_opened(
&mut self,
request: impl IntoRequest<TerminalOpenedNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_opened( &mut self, request: impl IntoRequest<TerminalOpenedNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Opened - Notification: Terminal opened
Sourcepub async fn accept_terminal_closed(
&mut self,
request: impl IntoRequest<TerminalClosedNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_closed( &mut self, request: impl IntoRequest<TerminalClosedNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Closed - Notification: Terminal closed
Sourcepub async fn accept_terminal_process_id(
&mut self,
request: impl IntoRequest<TerminalProcessIdNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_process_id( &mut self, request: impl IntoRequest<TerminalProcessIdNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Process ID - Notification: Terminal process ID
Sourcepub async fn accept_terminal_process_data(
&mut self,
request: impl IntoRequest<TerminalDataNotification>,
) -> Result<Response<Empty>, Status>
pub async fn accept_terminal_process_data( &mut self, request: impl IntoRequest<TerminalDataNotification>, ) -> Result<Response<Empty>, Status>
Accept Terminal Process Data - Notification: Terminal output
Sourcepub async fn register_tree_view_provider(
&mut self,
request: impl IntoRequest<RegisterTreeViewProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_tree_view_provider( &mut self, request: impl IntoRequest<RegisterTreeViewProviderRequest>, ) -> Result<Response<Empty>, Status>
Register Tree View Provider - Register a tree view provider
Sourcepub async fn get_tree_children(
&mut self,
request: impl IntoRequest<GetTreeChildrenRequest>,
) -> Result<Response<GetTreeChildrenResponse>, Status>
pub async fn get_tree_children( &mut self, request: impl IntoRequest<GetTreeChildrenRequest>, ) -> Result<Response<GetTreeChildrenResponse>, Status>
Get Tree Children - Request tree view children
Sourcepub async fn register_scm_provider(
&mut self,
request: impl IntoRequest<RegisterScmProviderRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_scm_provider( &mut self, request: impl IntoRequest<RegisterScmProviderRequest>, ) -> Result<Response<Empty>, Status>
Register SCM Provider - Register source control provider
Sourcepub async fn update_scm_group(
&mut self,
request: impl IntoRequest<UpdateScmGroupRequest>,
) -> Result<Response<Empty>, Status>
pub async fn update_scm_group( &mut self, request: impl IntoRequest<UpdateScmGroupRequest>, ) -> Result<Response<Empty>, Status>
Update SCM Group - Update SCM group
Sourcepub async fn git_exec(
&mut self,
request: impl IntoRequest<GitExecRequest>,
) -> Result<Response<GitExecResponse>, Status>
pub async fn git_exec( &mut self, request: impl IntoRequest<GitExecRequest>, ) -> Result<Response<GitExecResponse>, Status>
Execute Git - Execute git command
Sourcepub async fn register_debug_adapter(
&mut self,
request: impl IntoRequest<RegisterDebugAdapterRequest>,
) -> Result<Response<Empty>, Status>
pub async fn register_debug_adapter( &mut self, request: impl IntoRequest<RegisterDebugAdapterRequest>, ) -> Result<Response<Empty>, Status>
Register Debug Adapter - Register debug adapter
Sourcepub async fn start_debugging(
&mut self,
request: impl IntoRequest<StartDebuggingRequest>,
) -> Result<Response<StartDebuggingResponse>, Status>
pub async fn start_debugging( &mut self, request: impl IntoRequest<StartDebuggingRequest>, ) -> Result<Response<StartDebuggingResponse>, Status>
Start Debugging - Start debug session
Sourcepub async fn participate_in_save(
&mut self,
request: impl IntoRequest<ParticipateInSaveRequest>,
) -> Result<Response<ParticipateInSaveResponse>, Status>
pub async fn participate_in_save( &mut self, request: impl IntoRequest<ParticipateInSaveRequest>, ) -> Result<Response<ParticipateInSaveResponse>, Status>
Participate in Save - Extension participates in save
Sourcepub async fn get_secret(
&mut self,
request: impl IntoRequest<GetSecretRequest>,
) -> Result<Response<GetSecretResponse>, Status>
pub async fn get_secret( &mut self, request: impl IntoRequest<GetSecretRequest>, ) -> Result<Response<GetSecretResponse>, Status>
Get Secret - Retrieve a secret from storage
Sourcepub async fn store_secret(
&mut self,
request: impl IntoRequest<StoreSecretRequest>,
) -> Result<Response<Empty>, Status>
pub async fn store_secret( &mut self, request: impl IntoRequest<StoreSecretRequest>, ) -> Result<Response<Empty>, Status>
Store Secret - Store a secret in storage
Sourcepub async fn delete_secret(
&mut self,
request: impl IntoRequest<DeleteSecretRequest>,
) -> Result<Response<Empty>, Status>
pub async fn delete_secret( &mut self, request: impl IntoRequest<DeleteSecretRequest>, ) -> Result<Response<Empty>, Status>
Delete Secret - Delete a secret from storage